@@ -70,11 +70,15 @@ my $kraken = Finance::Crypto::Exchange::Kraken->new(%opts);
 
 sub _exec_kraken {
     my $command = shift;
+
     if ($kraken->can($command)) {
         print JSON::encode_json($kraken->$command), $/;
         return;
     }
-    die "Unable to execute command $command", $/;
+    die sprintf(
+        "Unable to execute command %s!\nPlease use one of the following: %s\n",
+        $command, join(", ", $kraken->supported_methods)
+    );
 }
 
 
@@ -99,7 +103,7 @@ kraken-cli - Kraken API via the CLI
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
